<?php

require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

function createOrUpdateDb() {
    // reset
    session_unset();
    session_start();

    // begin activation
    global $wpdb;
    global $informations_table_name;
    $informations_table_name = $wpdb->prefix . 'docage_informations';
    global $credentials_table_name;
    $credentials_table_name = $wpdb->prefix . 'docage_credentials';
    global $bindings_table_name;
    $bindings_table_name = $wpdb->prefix . 'docage_bindings';
    $charset_collate = $wpdb->get_charset_collate();

    if($wpdb->get_var("SHOW TABLES LIKE '$informations_table_name'") != $informations_table_name) {

        $sql = "CREATE TABLE $informations_table_name (
			Id int(10) NOT NULL AUTO_INCREMENT,
            PluginVersion   varchar(10) NOT NULL,
			PRIMARY KEY (Id)
		) $charset_collate;";

        dbDelta($sql);
    }



    if($wpdb->get_var("SHOW TABLES LIKE '$credentials_table_name'") != $credentials_table_name) {

        $sql = "CREATE TABLE $credentials_table_name (
			Id int(10) NOT NULL AUTO_INCREMENT,
			DocageUsername		varchar(150) NOT NULL UNIQUE,
			DocageApiKey 		varchar(150) NOT NULL,
			WPUserId            int(10) NOT NULL,
			Language            varchar(5) NOT NULL,
			IsActive            tinyint(1) NOT NULL,
			PRIMARY KEY (Id)
		) $charset_collate;";

        dbDelta( $sql ) ;
    }

    if($wpdb->get_var("SHOW TABLES LIKE '$bindings_table_name'") != $bindings_table_name) {

        $sql = "CREATE TABLE $bindings_table_name (
			Id 				int(10) 	NOT NULL AUTO_INCREMENT,
			CredentialsId	int(10)		NOT NULL,
			FormProvider	varchar(255) NOT NULL,
			TemplateType 	varchar(255) NOT NULL,
			FormId 			int(10) NOT NULL,
			TemplateId 		varchar(150) NOT NULL,
			FormFieldType 		varchar(255) NOT NULL,
			FormFieldName 		varchar(255) NOT NULL,
			TemplateObjectType 		varchar(255) NOT NULL,
			TemplateObjectName 		varchar(255) NOT NULL,
			/*TemplateObjectEntityType varchar (50) NOT NULL,*/
			/*TemplatePropertyType 	varchar(50) NOT NULL,*/
			TemplateObjectProperty 	varchar(255) NOT NULL,
			PRIMARY KEY (Id),
			FOREIGN KEY (CredentialsId)
            REFERENCES $credentials_table_name(Id)
            ON UPDATE CASCADE ON DELETE CASCADE
		) $charset_collate;";

        dbDelta( $sql );
    }

}

function Database_connect($action, $query) {
    if(!$query) return "Any provided data";

    try {
        $db = new PDO('mysql:host='.DB_HOST.';dbname='.DB_NAME.';charset=utf8', DB_USER, DB_PASSWORD);
        $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    } catch(Exception $e) {
        switch ($_SESSION['lang']) {
            case 'FR':
                Err_Msg("Il semble y avoir un problème avec la base de données WordPress.<br>
					Erreur : ".$e->getMessage());
                break;

            case 'EN':
                Err_Msg("It seems there's a problem with the Wordpress database.<br>
					Error : ".$e->getMessage());
                break;

            case 'ES':
                Err_Msg("Parece que hay un problema con la base de datos Wordpress.<br>
					Erreur : ".$e->getMessage());
                break;
        }
        exit();
    }

    if($action === "SELECT") {
        $result = null;

        try {
            $result = $db->query($query);
        } catch (Exception $e) {
            switch ($_SESSION['lang']) {
                case 'FR':
                    Err_Msg("Il semble y avoir un problème avec la base de données.<br>
					Erreur : ".$e->getMessage());
                    break;

                case 'EN':
                    Err_Msg("It seems there's a problem with the database.<br>
					Error : ".$e->getMessage());
                    break;

                case 'ES':
                    Err_Msg("Parece que hay un problema con la base de datos.<br>
					Erreur : ".$e->getMessage());
                    break;
            }
            die();
        }
        return $result;
    } else if($action === "ALTER") {
        return "Result for query :\n" . $query . "\n" . $db->exec($query);
    } else {
        switch ($_SESSION['lang']) {
            case 'FR':
                Err_Msg("Action : ".$action." Mauvaise action renseignée.");
                break;

            case 'EN':
                Err_Msg("Action : ".$action." Bad action filled.");
                break;

            case 'ES':
                Err_Msg("Action : ".$action." Action incorrecta informada.");
                break;
        }
        die();
    }
}