<?php

function getAllBindings(): array {
    $bindings_array = array();

    global $wpdb;
    $response = Database_connect("SELECT", 'SELECT * FROM '.$wpdb->prefix.'docage_bindings');

    while ($data = $response->fetch()) {
        $binding = new Binding();
        $binding->FormId = $data["FormId"];
        $binding->TemplateId = $data["TemplateId"];
        $binding->FormFieldName = $data["FormFieldName"];
        $binding->FormFieldType = $data["FormFieldType"];
        $binding->TemplateObjectType = $data["TemplateObjectType"];
        $binding->TemplateObjectName = $data["TemplateObjectName"];
        $binding->TemplateObjectProperty = $data["TemplateObjectProperty"];
        $bindings_array[] = $binding;
    }

    return $bindings_array;
}

function getAllWpForms(): array {
    $wpforms_array = array();

    global $wpdb;
    $response = Database_connect("SELECT", 'SELECT post_content FROM '.$wpdb->prefix.'posts WHERE post_type = "wpforms" AND post_status = "publish"');

    // Pour tous les WPForms en bdd,
    // on récupère les informations du form pour les rajouter à la liste des WPForms
    while ($data = $response->fetch()) {
        $json = json_decode($data[0]);

        $wpform = new WPForm();

        $wpform_fields = array();
        foreach ($json->fields as $field) {
            if ($field->type == "pagebreak" || $field->type == "divider" || $field->type == "html" || $field->type == "entry-preview" || !isset($field->label))
                continue;
            $wpform_field = new WPFormField();
            $wpform_field->Label = $field->label;
            $wpform_field->Type = $field->type;
            $wpform_fields[] = $wpform_field;
        }
        $wpform->Id = $json->id;
        $wpform->Title = $json->settings->form_title;
        $wpform->WPFormFields = $wpform_fields;
        $wpforms_array[] = $wpform;
    }
    $response->closeCursor();

    return $wpforms_array;
}

function getAllDocageTemplates(): array {
    $docage_templates = array();

    $response = Docage_API_request('GET','Transactions/true');

    foreach ($response[1] as $template) {
        $docage_template = new DocageTemplate();
        $docage_template->Id = $template->Id;
        $docage_template->Name = $template->Name;
        foreach ($template->MemberSummaries as $member) {
            $docage_template_member = new DocageTemplateMember();
            $docage_template_member->Type = "TransactionMember";
            $docage_template_member->Name = $member->FriendlyName != null ? $member->FriendlyName : $member->DisplayName;
            $docage_template->Members[] = $docage_template_member;
        }
        foreach ($template->FileSummaries as $file) {
            $docage_template_member = new DocageTemplateMember();
            $docage_template_member->Type = "TransactionFile";
            $docage_template_member->Name = $file->FriendlyName;
            $docage_template->Members[] = $docage_template_member;
        }

        $docage_templates[] = $docage_template;
    }
    return $docage_templates;
}

function getTransactionProperties(): array {
    $transaction_properties = array();

    $response = Docage_API_request('GET', "Transactions/CreationFieldsForZapier");
    foreach ($response[1] as $property) {
        $transaction_property = new DocageField();
        $transaction_property->Key = $property->key;
        $transaction_property->Label = $property->label;
        $transaction_properties[] = $transaction_property;
    }

    return $transaction_properties;
}

function getTransactionMemberProperties(): array {
    $transaction_member_properties = array();

    $response = Docage_API_request('GET', "Contacts/CreationFieldsForZapier");

    foreach ($response[1] as $property) {
        $transaction_member_property = new DocageField();
        $transaction_member_property->Key = $property->key;
        $transaction_member_property->Label = $property->label;
        $transaction_member_properties[] = $transaction_member_property;
    }

    return $transaction_member_properties;
}

/*function getTransactionFileProperties(): array {
    $transaction_file_properties = array();

    $response = Docage_API_request('GET', "TransactionFiles/CreationFieldsForZapier");
    console_log($response);

    foreach ($response[1] as $property) {
        $transaction_file_property = new DocageField();
        $transaction_file_property->Key = $property->key;
        $transaction_file_property->Label = $property->label;
        $transaction_files_properties[] = $transaction_file_property;
    }

    return $transaction_files_properties;
}*/

function getAllCustomFields($organizationId): stdClass {
    $custom_fields = array();

    $response = Docage_API_request('GET', "Organizations/AllDefaultCustomFields/$organizationId");

    $custom_fields = $response[1];

    return $custom_fields;
}